@@ -42,7 +42,7 @@ reUnderLineBegin = re.compile(r"<\s*u\s*>", re.IGNORECASE)
 reUnderLineEnd = re.compile(r"<\s*/\s*U\s*>", re.IGNORECASE)
 
 cm_2_inch = num(2.5396)
-points_in_mm = 2.834645669
+points_in_mm = num(2.834645669)
 points_in_cm = num(points_in_mm) * num(10)
 twip_in_cm = num(points_in_cm) * num(20)
 
@@ -222,14 +222,18 @@ class Q2PrinterXlsx(Q2Printer):
         if self.current_sheet:
             self.xlsx_sheets.append(self.current_sheet)
 
-    def render_rows_section(self, rows, style, outline_level):
-        super().render_rows_section(rows, style, outline_level)
-        row_count = len(rows["heights"])
+    def render_rows_section(self, rows_section, style, outline_level):
+        super().render_rows_section(rows_section, style, outline_level)
+        row_count = len(rows_section["heights"])
         spanned_cells = {}
 
         sheet_row = {}
         for row in range(row_count):  # вывод - по строкам
-            sheet_row["height"] = 15
+            # sheet_row["height"] = (
+            #     rows_section["real_heights"][row] if rows_section["real_heights"][row] else num(0.7)
+            # ) * points_in_cm
+
+            sheet_row["height"] = rows_section["max_cell_height"][row] * points_in_cm
             sheet_row["cells"] = []
             sheet_row["outline_level"] = outline_level
             for col in range(self._columns_count):  # цикл по клеткам строки
@@ -238,17 +242,19 @@ class Q2PrinterXlsx(Q2Printer):
                     sheet_row["cells"].append(spanned_cells[key])
                     continue
                 cell_address = self.get_cell_address(self.sheet_current_row, col)
-                cell_data = rows.get("cells", {}).get(key, {})
+                cell_data = rows_section.get("cells", {}).get(key, {})
                 cell_text = cell_data.get("data", "")
 
                 row_span = cell_data.get("rowspan", 1)
                 col_span = cell_data.get("colspan", 1)
-                cell_style = dict(style)
-                if cell_data.get("style", {}):
-                    cell_style.update(cell_data.get("style", {}))
+
+                cell_style = cell_data.get("style", {})
+                if cell_style == {}:
+                    cell_style = dict(style)
+                    # cell_data["style"] = cell_style
 
                 self.make_image(cell_data, row, col)
-                cell_xml = self.make_xlsx_cell(cell_address, cell_style, cell_text)
+                cell_xml = self.make_xlsx_cell(cell_address, cell_style, cell_text, cell_data)
                 sheet_row["cells"].append(cell_xml)
                 if row_span > 1 or col_span > 1:
                     merge_str = ":".join(
@@ -285,18 +291,16 @@ class Q2PrinterXlsx(Q2Printer):
 
         zipf.writestr("xl/styles.xml", (xlsx_parts["xl/styles.xml"] % locals()).encode("utf8"))
 
-    def get_cell_xf_id(self, style):
+    def get_cell_xf_id(self, style, numFmtId=0):
         border = f'borderId="{self.get_cell_borders(style)}"'
         fill = f'fillId="{0}"'
         font = f'fontId="{self.get_font_id(style)}"'
-        num_fmt = f'numFmtId="{0}"'
+        num_fmt = f'numFmtId="{numFmtId}"'
         align = self.get_cell_align(style)
 
         cell_xfs = f'<xf {border} {fill} {font} {num_fmt} xfId="0" applyAlignment="true"> {align} </xf>'
         if cell_xfs not in self.cell_xfs:
             self.cell_xfs.append(cell_xfs)
-        #     xf_id = len(self.cell_xfs) - 1
-        # else:
         xf_id = self.cell_xfs.index(cell_xfs)
 
         return xf_id
@@ -315,7 +319,7 @@ class Q2PrinterXlsx(Q2Printer):
 
     def make_image(self, cell_data, row, col):
         for x in cell_data.get("images", []):
-            width, height, imageIndex = self.prepare_image(x, col)
+            width, height, imageIndex = self.prepare_image(x, cell_data.get("width"))
 
             width = num(width) * num(12700) * points_in_cm
             height = num(height) * num(12700) * points_in_cm
@@ -328,11 +332,21 @@ class Q2PrinterXlsx(Q2Printer):
             tmp_drawing["_width"] = int(width)
             self.current_sheet["drawing"].append(tmp_drawing)
 
-    def make_xlsx_cell(self, cell_address, cell_style, cell_text):
+    def make_xlsx_cell(self, cell_address, cell_style, cell_text, cell_data={}):
+        if cell_data.get("numFmtId"):
+            xf_id = self.get_cell_xf_id(cell_style, cell_data.get("numFmtId"))
+            return f"""\n\t<c r="{cell_address}"
+                            s="{xf_id}"
+                            t="n">
+                    <v>{cell_data.get("xlsx_data")}</v>
+                    \n\t</c>"""
+
         fontsizemod = fontsize = cell_style["font-size"].replace("pt", "")
         fontfamily = cell_style["font-family"]
 
         cell_content = []
+        cell_text = cell_text.replace("\n", "")
+        cell_text = cell_text.replace("\r", "")
         cell_text = reMultiSpaceDelete.sub(" ", cell_text)
         cell_text = reHtmlTagBr.sub("\n", cell_text)
         if re.findall(r"\<(\/*b)|(br/)|(font)|(u)|(i)\>", cell_text, re.IGNORECASE):
@@ -370,7 +384,9 @@ class Q2PrinterXlsx(Q2Printer):
                     )
         elif cell_text != "":
             cell_content.append(f'<t xml:space="preserve">{cell_text}</t>')
+
         xf_id = self.get_cell_xf_id(cell_style)
+
         if cell_content:
             cell_content = "".join(cell_content)
             if cell_content not in self.sharedStrings:
@@ -378,34 +394,46 @@ class Q2PrinterXlsx(Q2Printer):
                 shared_strings_id = len(self.sharedStrings) - 1
             else:
                 shared_strings_id = self.sharedStrings.index(cell_content)
-            return (
-                f'\n\t<c r="{cell_address}" s="{xf_id}" ' f't="s"> \n\t\t<v>{shared_strings_id}</v> \n\t</c>'
-            )
+            return f"""\n\t<c r="{cell_address}"
+                            s="{xf_id}"
+                            t="s">
+                    \n\t\t<v>{shared_strings_id}</v>
+                    \n\t</c>"""
+            # return (
+            #     f'''\n\t<c r="{cell_address}"
+            #                 s="2"
+            #                 t="n">
+            #         <v>123</v>
+            #         \n\t</c>'''
+            # )
         else:
             return f'\n\t<c r="{cell_address}" s="{xf_id}"/> '
 
-    def get_cell_align(self, style):
-        padding = style["padding"].replace("cm", "").split(" ")
+    def get_cell_align(self, cell_style):
 
-        if style["vertical-align"] == "middle":
+        if cell_style["vertical-align"] == "middle":
             vertical = 'vertical="center"'
-        elif style["vertical-align"] == "top":
+        elif cell_style["vertical-align"] == "top":
             vertical = 'vertical="top"'
         else:
             vertical = ""
 
-        if style["text-align"] == "center":
+        padding = cell_style["padding"].replace("cm", "").split(" ")
+        while len(padding) < 4:
+            padding += padding
+
+        if cell_style["text-align"] == "center":
             horizontal = 'horizontal="center"'
-        elif style["text-align"] == "right":
+        elif cell_style["text-align"] == "right":
             horizontal = 'horizontal="right"'
-            if style["padding"][1]:
-                horizontal += f""" indent="{int(round(num(padding[2]) / num(0.25)))}" """
-        elif style["text-align"] == "justify":
+            if padding[1]:
+                horizontal += f""" indent="{int(round(num(padding[1]) / num(0.25)))}" """
+        elif cell_style["text-align"] == "justify":
             horizontal = 'horizontal="justify"'
         else:
             horizontal = ""
-            if style["padding"][3]:
-                horizontal = f""" indent="{int(round((num(padding[3])) / num(0.25)))}" """
+            if padding[3]:
+                horizontal = f""" horizontal="left" indent="{int(round((num(padding[3])) / num(0.25)))}" """
         return f'\n\t<alignment {horizontal} {vertical} wrapText="true"/>\n'
 
     def get_cell_borders(self, style):
@@ -413,7 +441,7 @@ class Q2PrinterXlsx(Q2Printer):
         while len(border_width) < 4:
             border_width += border_width
         border = []
-        for index, side in enumerate(("top", "right", "bottom", "left")):
+        for index, side in enumerate(("left", "right", "top", "bottom")):
             if int_(border_width[index]):
                 bw = self.get_border_width(border_width[index])
                 border.append(f'<{side} style="{bw}"><color auto="1"/></{side}>')
